hashed_wedge

Function hashed_wedge 

pub fn hashed_wedge(
    x1: f64,
    y1: f64,
    x2: f64,
    y2: f64,
    half: Option<f64>,
    n: Option<usize>,
) -> Vec<StrokePath>
Hashed wedge for a bond going away from the viewer.

(x1, y1) is the stereocenter. Hashes are wide there and narrow at the substituent.