pub fn stroke_frac_from_stem(stem_em: f64) -> f64Expand description
Bond stroke fraction from a stem width in em (rounded like STROKE_FRAC).
pub fn stroke_frac_from_stem(stem_em: f64) -> f64Bond stroke fraction from a stem width in em (rounded like STROKE_FRAC).